========================
Core Explore Keyword App
========================

Exploration by keywords for the curator core project.

Quickstart
==========

1. Add "core_explore_keyword_app" to your INSTALLED_APPS setting
----------------------------------------------------------------

.. code:: python

    INSTALLED_APPS = [
        ...
        'core_explore_keyword_app',
    ]
